# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['severino',
 'severino.sdk',
 'severino.sdk.airflow',
 'severino.sdk.helpers',
 'severino.sdk.internal_recruitment',
 'severino.sdk.reports_of_pcds_in_admission',
 'severino.sdk.rescission_workflow',
 'severino.sdk.store_data']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.27.1,<3.0.0']

setup_kwargs = {
    'name': 'severino',
    'version': '0.2.1',
    'description': 'O Severino é utilizado para facilitar as integrações e também a reutilização de código',
    'long_description': None,
    'author': 'Stone People Analytics',
    'author_email': 'systems-techpeople@stone.com.br',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



from severino.sdk.store_data import StoreData


class StoreDataTmp(StoreData):
    def __init__(self):
        super().__init__()
        self.path = "/store-data/store/tmp/"

    def create(self, airflow_dag_id: str, json_data: dict, runtime_id: str = ""):
        return self.http.post(
            url=f"{self.severino_api_url}{self.path}",
            data={
                airflow_dag_id: airflow_dag_id,
                json_data: json_data,
                runtime_id: runtime_id,
            },
        )
